# Febraban Barcode

[![Documentation Status](https://readthedocs.org/projects/febraban-barcode/badge/?version=stable)](https://febraban-barcode.readthedocs.io/pt_BR/stable/?badge=stable)

Implementação em python do layout padrão de arrecadação/recebimento com utilização do código de barras da Febraban.

## Instalação

```bash
pip install febraban_barcode
```
